Initialise built-in Shiny application
Value
Called for its side effect of launching the wowi Shiny
application in the user's default web browser. Returns NULL
invisibly when the app session ends.
Examples
if(interactive()) ww_run_app()
Initialise built-in Shiny application
Called for its side effect of launching the wowi Shiny
application in the user's default web browser. Returns NULL
invisibly when the app session ends.
if(interactive()) ww_run_app()